fee_totals

Function fee_totals 

fn fee_totals(
    receipts: impl IntoIterator<Item = (u64, u128)>,
) -> (u64, Option<u128>, u128)
Returns the total gas used, the average gas price and the total fee paid in wei for the given (gas_used, effective_gas_price) receipt pairs.